# Generated by roxygen2: do not edit by hand

export(binom.ci)
export(cvar)
export(eta2)
export(gg_qqplot)
export(panel.hist)
export(plotcdf2)
export(poi.ci)
import(ggplot2)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,gray)
importFrom(graphics,hist)
importFrom(graphics,par)
importFrom(graphics,persp)
importFrom(graphics,rect)
importFrom(stats,as.formula)
importFrom(stats,lm)
importFrom(stats,qchisq)
importFrom(stats,qf)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,sd)
